Contributed-under: TianoCore Contribution Agreement 1.0
Cc: Liming Gao <liming....@intel.com>
Cc: Eric Dong <eric.d...@intel.com>
Cc: Dandan Bi <dandan...@intel.com>
Signed-off-by: Ruiyu Ni <ruiyu...@intel.com>
---
 .../HiiDatabaseDxe/ConfigKeywordHandler.c          | 36 +++++++-------
 .../Universal/HiiDatabaseDxe/ConfigRouting.c       | 58 +++++++++++-----------
 MdeModulePkg/Universal/HiiDatabaseDxe/Database.c   | 14 +++---
 MdeModulePkg/Universal/HiiDatabaseDxe/Font.c       | 32 ++++++------
 .../Universal/HiiDatabaseDxe/HiiDatabaseEntry.c    |  2 +-
 5 files changed, 71 insertions(+), 71 deletions(-)

diff --git a/MdeModulePkg/Universal/HiiDatabaseDxe/ConfigKeywordHandler.c 
b/MdeModulePkg/Universal/HiiDatabaseDxe/ConfigKeywordHandler.c
index 10a901f..ae5cff2 100644
--- a/MdeModulePkg/Universal/HiiDatabaseDxe/ConfigKeywordHandler.c
+++ b/MdeModulePkg/Universal/HiiDatabaseDxe/ConfigKeywordHandler.c
@@ -28,7 +28,7 @@ extern HII_DATABASE_PRIVATE_DATA mPrivate;
   @param  NextString             string follow the possible PathHdr string.
 
   @retval EFI_INVALID_PARAMETER  The device path is not valid or the incoming 
parameter is invalid.
-  @retval EFI_OUT_OF_RESOURCES   Lake of resources to store neccesary 
structures.
+  @retval EFI_OUT_OF_RESOURCES   Lake of resources to store necessary 
structures.
   @retval EFI_SUCCESS            The device path is retrieved and translated 
to binary format.
                                  The Input string not include PathHdr section.
 
@@ -240,10 +240,10 @@ ExtractNameSpace (
 
   @param  String                 KeywordRequestformat string.
   @param  Keyword                return the extract keyword string.
-  @param  NextString             return the next string follow this keyword 
sectin.
+  @param  NextString             return the next string follow this keyword 
section.
 
   @retval EFI_SUCCESS            Success to get the keyword string.
-  @retval EFI_INVALID_PARAMETER  Parsr the input string return error.
+  @retval EFI_INVALID_PARAMETER  Parse the input string return error.
 
 **/
 EFI_STATUS
@@ -306,10 +306,10 @@ ExtractKeyword (
 
   @param  String                 KeywordRequestformat string.
   @param  Value                  return the extract value string.
-  @param  NextString             return the next string follow this keyword 
sectin.
+  @param  NextString             return the next string follow this keyword 
section.
 
   @retval EFI_SUCCESS            Success to get the keyword string.
-  @retval EFI_INVALID_PARAMETER  Parsr the input string return error.
+  @retval EFI_INVALID_PARAMETER  Parse the input string return error.
 
 **/
 EFI_STATUS
@@ -361,10 +361,10 @@ ExtractValue (
 
   @param  String                 KeywordRequestformat string.
   @param  FilterFlags            return the filter condition.
-  @param  NextString             return the next string follow this keyword 
sectin.
+  @param  NextString             return the next string follow this keyword 
section.
 
   @retval EFI_SUCCESS            Success to get the keyword string.
-  @retval EFI_INVALID_PARAMETER  Parsr the input string return error.
+  @retval EFI_INVALID_PARAMETER  Parse the input string return error.
 
 **/
 BOOLEAN
@@ -477,7 +477,7 @@ ExtractFilter (
         String = KeywordPtr;
       } else {
         //
-        // Only has paltform defined filter section, just skip it.
+        // Only has platform defined filter section, just skip it.
         //
         String += StrLen (String);
       }
@@ -520,9 +520,9 @@ ExtractReadOnlyFromOpCode (
 
   This is a internal function.
 
-  @param  OpCodeData             The questin binary ifr data.
+  @param  OpCodeData             The question binary ifr data.
   @param  KeywordRequest         KeywordRequestformat string.
-  @param  NextString             return the next string follow this keyword 
sectin.
+  @param  NextString             return the next string follow this keyword 
section.
   @param  ReadOnly               Return whether this question is read only.
 
   @retval KEYWORD_HANDLER_NO_ERROR                     Success validate.
@@ -711,7 +711,7 @@ GetRecordFromDevicePath (
   @param  BufferSize             Length of the buffer.
   @param  StringDest             Buffer to store the string text. 
 
-  @retval EFI_SUCCESS            The string text was outputed successfully.
+  @retval EFI_SUCCESS            The string text was outputted successfully.
   @retval EFI_OUT_OF_RESOURCES   Out of resource.
 
 **/
@@ -1310,7 +1310,7 @@ GetNextStringId (
   @param  KeywordValue                   Keyword value.
   @param  StringId                       String Id for this keyword.
 
-  @retval KEYWORD_HANDLER_NO_ERROR                     Get String id succes.
+  @retval KEYWORD_HANDLER_NO_ERROR                     Get String id 
successfully.
   @retval KEYWORD_HANDLER_KEYWORD_NOT_FOUND            Not found the string id 
in the string package.
   @retval KEYWORD_HANDLER_NAMESPACE_ID_NOT_FOUND       Not found the string 
package for this namespace.
   @retval KEYWORD_HANDLER_UNDEFINED_PROCESSING_ERROR   Out of resource error.
@@ -1609,7 +1609,7 @@ GetWidth (
 }
 
 /**
-  Converts all hex dtring characters in range ['A'..'F'] to ['a'..'f'] for 
+  Converts all hex string characters in range ['A'..'F'] to ['a'..'f'] for 
   hex digits that appear between a '=' and a '&' in a config string.
 
   If ConfigString is NULL, then ASSERT().
@@ -1657,7 +1657,7 @@ InternalLowerConfigString (
   @param[in]  DriverHandle  The driver handle which supports a Device Path 
Protocol
                             that is the routing information PATH.  Each byte of
                             the Device Path associated with DriverHandle is 
converted
-                            to a 2 Unicode character hexidecimal string.
+                            to a 2 Unicode character hexadecimal string.
 
   @retval NULL   DriverHandle does not support the Device Path Protocol.
   @retval Other  A pointer to the Null-terminate Unicode <ConfigHdr> string
@@ -2356,7 +2356,7 @@ GetStringIdFromDatabase (
 }
 
 /**
-  Genereate the KeywordResp String.
+  Generate the KeywordResp String.
 
   <KeywordResp> ::= 
<NameSpaceId><PathHdr>'&'<Keyword>'&VALUE='<Number>['&READONLY']
 
@@ -2419,7 +2419,7 @@ GenerateKeywordResp (
   RespStrLen += StrLen (PathHdr);
 
   //
-  // 1.3 Keyword setion.
+  // 1.3 Keyword section.
   // 'KEYWORD='<String>[':'<DecCh>(1/4)]
   //
   RespStrLen += 8 + StrLen (KeywordData);
@@ -2709,7 +2709,7 @@ Error:
   }
 
   //
-  // return the already get MultiKeywordString even error occured.
+  // return the already get MultiKeywordString even error occurred.
   //
   if (MultiKeywordResp == NULL) {
     Status = EFI_NOT_FOUND;
@@ -3071,7 +3071,7 @@ Done:
   @retval EFI_SUCCESS             The specified action was completed 
successfully.
   
   @retval EFI_INVALID_PARAMETER   One or more of the following are TRUE:
-                                  1.Progress, ProgressErr, or Resuts is NULL.
+                                  1.Progress, ProgressErr, or Results is NULL.
                                   2.Parsing of the KeywordString resulted in 
an error. See
                                     Progress and ProgressErr for more data.
   
diff --git a/MdeModulePkg/Universal/HiiDatabaseDxe/Database.c 
b/MdeModulePkg/Universal/HiiDatabaseDxe/Database.c
index 984c5d2..4fd83f8 100644
--- a/MdeModulePkg/Universal/HiiDatabaseDxe/Database.c
+++ b/MdeModulePkg/Universal/HiiDatabaseDxe/Database.c
@@ -356,7 +356,7 @@ InvokeRegisteredFunction (
   @param  NotifyType             The type of change concerning the database.
   @param  PackageList            Pointer to a package list which will be 
inserted
                                  to.
-  @param  Package                Created GUID pacakge
+  @param  Package                Created GUID package
 
   @retval EFI_SUCCESS            Guid Package is inserted successfully.
   @retval EFI_OUT_OF_RESOURCES   Unable to allocate necessary resources for 
the new
@@ -903,7 +903,7 @@ Error:
  @param  PackageList        Pointer to a package list which will be adjusted.
 
  @retval EFI_SUCCESS  Adjust all string packages successfully.
- @retval others       Can't adjust string packges.
+ @retval others       Can't adjust string packages.
 
 **/
 EFI_STATUS
@@ -3041,7 +3041,7 @@ HiiNewPackageList (
 
 
 /**
-  This function removes the package list that is associated with a handle 
Handle
+  This function removes the package list that is associated with Handle
   from the HII database. Before removing the package, any registered functions
   with the notification type REMOVE_PACK and the same package type will be 
called.
 
@@ -3052,7 +3052,7 @@ HiiNewPackageList (
 
   @retval EFI_SUCCESS            The data associated with the Handle was 
removed
                                  from  the HII database.
-  @retval EFI_NOT_FOUND          The specified andle is not in database.
+  @retval EFI_NOT_FOUND          The specified handle is not in database.
   @retval EFI_INVALID_PARAMETER  The Handle was not valid.
 
 **/
@@ -3294,7 +3294,7 @@ HiiUpdatePackageList (
                                  buffer that is required for the handles found.
   @param  Handle                 An array of EFI_HII_HANDLE instances returned.
 
-  @retval EFI_SUCCESS            The matching handles are outputed 
successfully.
+  @retval EFI_SUCCESS            The matching handles are outputted 
successfully.
                                  HandleBufferLength is updated with the actual 
length.
   @retval EFI_BUFFER_TO_SMALL    The HandleBufferLength parameter indicates 
that
                                  Handle is too small to support the number of
@@ -3400,7 +3400,7 @@ HiiListPackageLists (
         }
         break;
         //
-        // Pesudo-type EFI_HII_PACKAGE_TYPE_ALL will cause all package handles
+        // Pseudo-type EFI_HII_PACKAGE_TYPE_ALL will cause all package handles
         // to be listed.
         //
       case EFI_HII_PACKAGE_TYPE_ALL:
@@ -3457,7 +3457,7 @@ HiiListPackageLists (
                                  Handle is too small to support the number of
                                  handles.      HandleBufferLength is updated 
with a
                                  value that will enable the data to fit.
-  @retval EFI_NOT_FOUND          The specifiecd Handle could not be found in 
the
+  @retval EFI_NOT_FOUND          The specified Handle could not be found in the
                                  current database.
   @retval EFI_INVALID_PARAMETER  BufferSize was NULL.
   @retval EFI_INVALID_PARAMETER  The value referenced by BufferSize was not 
zero 
diff --git a/MdeModulePkg/Universal/HiiDatabaseDxe/Font.c 
b/MdeModulePkg/Universal/HiiDatabaseDxe/Font.c
index 7e5d3bd..348c428 100644
--- a/MdeModulePkg/Universal/HiiDatabaseDxe/Font.c
+++ b/MdeModulePkg/Universal/HiiDatabaseDxe/Font.c
@@ -275,7 +275,7 @@ GetGlyphBuffer (
   @param  RowWidth       The width of the text on the line, in pixels.
   @param  RowHeight      The height of the line, in pixels.
   @param  Transparent    If TRUE, the Background color is ignored and all
-                         "off" pixels in the character's drawn wil use the
+                         "off" pixels in the character's drawn will use the
                          pixel value from BltBuffer.
   @param  Origin         On input, points to the origin of the to be
                          displayed character, on output, points to the
@@ -351,7 +351,7 @@ NarrowGlyphToBlt (
   @param  RowWidth                The width of the text on the line, in pixels.
   @param  RowHeight               The height of the line, in pixels.
   @param  Transparent             If TRUE, the Background color is ignored and 
all
-                                  "off" pixels in the character's drawn wil 
use the
+                                  "off" pixels in the character's drawn will 
use the
                                   pixel value from BltBuffer.
   @param  Cell                    Points to EFI_HII_GLYPH_INFO structure.
   @param  Attributes              The attribute of incoming glyph in 
GlyphBuffer.
@@ -467,7 +467,7 @@ GlyphToBlt (
   @param  RowWidth                The width of the text on the line, in pixels.
   @param  RowHeight               The height of the line, in pixels.
   @param  Transparent             If TRUE, the Background color is ignored and 
all
-                                  "off" pixels in the character's drawn wil 
use the
+                                  "off" pixels in the character's drawn will 
use the
                                   pixel value from BltBuffer.
   @param  Cell                    Points to EFI_HII_GLYPH_INFO structure.
   @param  Attributes              The attribute of incoming glyph in 
GlyphBuffer.
@@ -593,7 +593,7 @@ GlyphToImage (
   @param  InputCell               Buffer which stores cell information of the
                                   encoded bitmap.
   @param  GlyphBuffer             Output the corresponding bitmap data of the 
found
-                                  block. It is the caller's responsiblity to 
free
+                                  block. It is the caller's responsibility to 
free
                                   this buffer.
   @param  Cell                    Output cell information of the encoded 
bitmap.
   @param  GlyphBufferLen          If not NULL, output the length of 
GlyphBuffer.
@@ -647,7 +647,7 @@ WriteOutputParam (
   @param  CharValue               Unicode character value, which identifies a 
glyph
                                   block.
   @param  GlyphBuffer             Output the corresponding bitmap data of the 
found
-                                  block. It is the caller's responsiblity to 
free
+                                  block. It is the caller's responsibility to 
free
                                   this buffer.
   @param  Cell                    Output cell information of the encoded 
bitmap.
   @param  GlyphBufferLen          If not NULL, output the length of 
GlyphBuffer.
@@ -1143,7 +1143,7 @@ Exit:
   @param  FontHandle              On entry, Points to the font handle returned 
by a
                                   previous  call to GetFontInfo() or NULL to 
start
                                   with the first font.
-  @param  GlobalFontInfo          If not NULL, output the corresponding globa 
font
+  @param  GlobalFontInfo          If not NULL, output the corresponding global 
font
                                   info.
 
   @retval TRUE                    Existed
@@ -1172,7 +1172,7 @@ IsFontInfoExisted (
   ASSERT (FontInfo != NULL);
 
   //
-  // Matched flag represents an exactly match; VagueMatched1 repensents a 
RESIZE
+  // Matched flag represents an exactly match; VagueMatched1 represents a 
RESIZE
   // or RESTYLE match; VagueMatched2 represents a RESIZE | RESTYLE match.
   //
   Matched           = FALSE;
@@ -1248,7 +1248,7 @@ IsFontInfoExisted (
         }
         break;
       //
-      // If EFI_FONT_INFO_RESIZE is specified, then the sytem may attempt to
+      // If EFI_FONT_INFO_RESIZE is specified, then the system may attempt to
       // stretch or shrink a font to meet the size requested.
       //
       case EFI_FONT_INFO_ANY_FONT | EFI_FONT_INFO_RESIZE:
@@ -1747,8 +1747,8 @@ HiiStringToImage (
   }
   
   //
-  // Use the maxinum height of font as the base line.
-  // And, use the maxinum height as line height.
+  // Use the maximum height of font as the base line.
+  // And, use the maximum height as line height.
   //
   LineHeight     = Height;
   LastLineHeight = Height;
@@ -1783,7 +1783,7 @@ HiiStringToImage (
   }
   //
   // If EFI_HII_IGNORE_IF_NO_GLYPH is set, then characters which have no glyphs
-  // are not drawn. Otherwise they are replaced wth Unicode character 0xFFFD.
+  // are not drawn. Otherwise they are replaced with Unicode character 0xFFFD.
   //
   StringIn2  = AllocateZeroPool (StrSize (StringPtr));
   if (StringIn2 == NULL) {
@@ -2074,7 +2074,7 @@ HiiStringToImage (
       for (Index1 = RowInfo[RowIndex].StartIndex; Index1 <= 
RowInfo[RowIndex].EndIndex; Index1++) {
         if (RowInfo[RowIndex].LineWidth > 0 && RowInfo[RowIndex].LineWidth > 
LineOffset) {
           //
-          // Only BLT these character which have corrsponding glyph in font 
basebase.
+          // Only BLT these character which have corresponding glyph in font 
database.
           //
           GlyphToImage (
             GlyphBuf[Index1],
@@ -2124,7 +2124,7 @@ HiiStringToImage (
       }
     } else {
       //
-      // Save the starting position for calculate the starting postition of 
next row. 
+      // Save the starting position for calculate the starting position of 
next row. 
       //
       RowBufferPtr = BufferPtr;
       //
@@ -2134,7 +2134,7 @@ HiiStringToImage (
       for (Index1 = RowInfo[RowIndex].StartIndex; Index1 <= 
RowInfo[RowIndex].EndIndex; Index1++) {
         if (RowInfo[RowIndex].LineWidth > 0 && RowInfo[RowIndex].LineWidth > 
LineOffset) {
           //
-          // Only BLT these character which have corrsponding glyph in font 
basebase.
+          // Only BLT these character which have corresponding glyph in font 
database.
           //
           GlyphToImage (
             GlyphBuf[Index1],
@@ -2304,8 +2304,8 @@ Exit:
                                   RowInfoArray or Blt.
   @retval EFI_INVALID_PARAMETER  The Blt or PackageList was NULL.
   @retval EFI_INVALID_PARAMETER  Flags were invalid combination.
-  @retval EFI_NOT_FOUND         The specified PackageList is not in the 
Database or the stringid is not 
-                          in the specified PackageList. 
+  @retval EFI_NOT_FOUND          The specified PackageList is not in the 
Database or the string id is not 
+                                  in the specified PackageList. 
 
 **/
 EFI_STATUS
diff --git a/MdeModulePkg/Universal/HiiDatabaseDxe/HiiDatabaseEntry.c 
b/MdeModulePkg/Universal/HiiDatabaseDxe/HiiDatabaseEntry.c
index 03a4184..b48254f 100644
--- a/MdeModulePkg/Universal/HiiDatabaseDxe/HiiDatabaseEntry.c
+++ b/MdeModulePkg/Universal/HiiDatabaseDxe/HiiDatabaseEntry.c
@@ -160,7 +160,7 @@ OnReadyToBoot (
   @retval EFI_SUCCESS    The Hii database is setup correctly.
   @return Other value if failed to create the default event for
           gHiiKeyboardLayoutChanged. Check gBS->CreateEventEx for
-          details. Or failed to insatll the protocols.
+          details. Or failed to install the protocols.
           Check gBS->InstallMultipleProtocolInterfaces for details.
           Or failed to create Ready To Boot Event.
           Check EfiCreateEventReadyToBootEx for details.
diff --git a/MdeModulePkg/Universal/HiiDatabaseDxe/ConfigRouting.c 
b/MdeModulePkg/Universal/HiiDatabaseDxe/ConfigRouting.c
index 9f036a5..b3fdc26 100644
--- a/MdeModulePkg/Universal/HiiDatabaseDxe/ConfigRouting.c
+++ b/MdeModulePkg/Universal/HiiDatabaseDxe/ConfigRouting.c
@@ -65,7 +65,7 @@ CalculateConfigStringLen (
 
   @retval EFI_NOT_FOUND          The device path is not invalid.
   @retval EFI_INVALID_PARAMETER  Any incoming parameter is invalid.
-  @retval EFI_OUT_OF_RESOURCES   Lake of resources to store neccesary 
structures.
+  @retval EFI_OUT_OF_RESOURCES   Lake of resources to store necessary 
structures.
   @retval EFI_SUCCESS            The device path is retrieved and translated to
                                  binary format.
 
@@ -436,7 +436,7 @@ AppendToMultiString (
                                  to free memory.
   @param  Len                    Length of the <Number>, in characters.
 
-  @retval EFI_OUT_OF_RESOURCES   Insufficient resources to store neccessary
+  @retval EFI_OUT_OF_RESOURCES   Insufficient resources to store necessary
                                  structures.
   @retval EFI_SUCCESS            Value of <Number> is outputted in Number
                                  successfully.
@@ -518,7 +518,7 @@ Exit:
   @param  Found                  The Block whether has been found.
   @param  BufferLen              The length of the buffer.
 
-  @retval EFI_OUT_OF_RESOURCES   Insufficient resources to store neccessary 
structures.
+  @retval EFI_OUT_OF_RESOURCES   Insufficient resources to store necessary 
structures.
   @retval EFI_SUCCESS            The function finishes successfully.
 
 **/
@@ -574,7 +574,7 @@ FindSameBlockElement(
   @param  AltConfigHdr           Pointer to a Unicode string in <AltConfigHdr> 
format.
   @param  ConfigAltRespChanged   Whether the ConfigAltResp has been changed.
 
-  @retval EFI_OUT_OF_RESOURCES   Insufficient resources to store neccessary 
structures.
+  @retval EFI_OUT_OF_RESOURCES   Insufficient resources to store necessary 
structures.
   @retval EFI_SUCCESS            The function finishes  successfully.
 
 **/
@@ -715,7 +715,7 @@ Exit:
   @param  AltConfigHdr           Pointer to a Unicode string in <AltConfigHdr> 
format.
   @param  ConfigAltRespChanged   Whether the ConfigAltResp has been changed.
 
-  @retval EFI_OUT_OF_RESOURCES   Insufficient resources to store neccessary 
structures.
+  @retval EFI_OUT_OF_RESOURCES   Insufficient resources to store necessary 
structures.
   @retval EFI_SUCCESS            The function finishes  successfully.
 
 **/
@@ -845,7 +845,7 @@ Exit:
                                  string for the different varstore buffer.
   @param  AltConfigHdr           Pointer to a Unicode string in <AltConfigHdr> 
format.
 
-  @retval EFI_OUT_OF_RESOURCES   Insufficient resources to store neccessary
+  @retval EFI_OUT_OF_RESOURCES   Insufficient resources to store necessary
                                  structures.
   @retval EFI_SUCCESS            The function finishes  successfully.
 
@@ -1021,7 +1021,7 @@ MergeDefaultString (
   }
   
   //
   // Get the requestr ConfigHdr
   //
   SizeAltCfgResp  = 0;
   StringPtr       = *AltCfgResp;
@@ -1249,9 +1249,9 @@ InsertBlockData (
   @param[in]  HiiHandle  A handle that was previously registered in the HII 
Database.
 
   @retval NULL   HiiHandle is not registered in the HII database
-  @retval NULL   There are not enough resources available to retrieve the 
suported 
+  @retval NULL   There are not enough resources available to retrieve the 
supported 
                  languages.
-  @retval NULL   The list of suported languages could not be retrieved.
+  @retval NULL   The list of supported languages could not be retrieved.
   @retval Other  A pointer to the Null-terminated ASCII string of supported 
languages.
 
 **/
@@ -1697,7 +1697,7 @@ GetVarStoreType (
       } 
         
       //
-      // Free alllocated temp string.
+      // Free allocated temp string.
       //
       FreePool (VarStoreName);
       FreePool (GuidStr);
@@ -1755,8 +1755,8 @@ GetElementsFromRequest (
   @param  Name              Varstore name.
   @param  ConfigHdr         Current configRequest info.
 
-  @retval  TRUE              This varstore is the requst one.
-  @retval  FALSE             This varstore is not the requst one.
+  @retval  TRUE              This varstore is the request one.
+  @retval  FALSE             This varstore is not the request one.
                                  
 **/
 BOOLEAN
@@ -1825,8 +1825,8 @@ Done:
   @param  DataBaseRecord        The DataBaseRecord instance contains the found 
Hii handle and package.
   @param  ConfigHdr             Request string ConfigHdr. If it is NULL,
                                 the first found varstore will be as ConfigHdr.
-  @retval  TRUE                 This hii package is the reqeust one.
-  @retval  FALSE                This hii package is not the reqeust one.
+  @retval  TRUE                 This hii package is the request one.
+  @retval  FALSE                This hii package is not the request one.
 **/                                
 BOOLEAN
 IsThisPackageList (
@@ -1955,7 +1955,7 @@ Done:
 
   @param  RequestBlockArray      The array includes all the request info or 
NULL.
   @param  HiiHandle              The hii handle for this form package.
-  @param  VarStorageData         The varstore data strucure.
+  @param  VarStorageData         The varstore data structure.
   @param  IfrOpHdr               Ifr opcode header for this opcode.
   @param  VarWidth               The buffer width for this opcode.
   @param  ReturnData             The data block added for this opcode.
@@ -2048,7 +2048,7 @@ IsThisOpcodeRequired (
 
   @param  HiiHandle             Hii Handle for this hii package.
   @param  Package               Pointer to the form package data.
-  @param  PackageLength         Length of the pacakge.
+  @param  PackageLength         Length of the package.
   @param  ConfigHdr             Request string ConfigHdr. If it is NULL,
                                 the first found varstore will be as ConfigHdr.
   @param  RequestBlockArray     The block array is retrieved from the request 
string.
@@ -2056,7 +2056,7 @@ IsThisOpcodeRequired (
   @param  DefaultIdArray        Point to the got default id and default name 
array.
 
   @retval EFI_SUCCESS           The block array and the default value array 
are got.
-  @retval EFI_INVALID_PARAMETER The varstore defintion in the differnt form 
pacakges
+  @retval EFI_INVALID_PARAMETER The varstore definition in the different form 
packages
                                 are conflicted. 
   @retval EFI_OUT_OF_RESOURCES  No enough memory.
 **/
@@ -2493,7 +2493,7 @@ ParseIfrData (
       DefaultData.DefaultId   = VarDefaultId;
       if ((IfrCheckBox->Flags & EFI_IFR_CHECKBOX_DEFAULT) == 
EFI_IFR_CHECKBOX_DEFAULT) {
         //
-        // When flag is set, defautl value is TRUE.
+        // When flag is set, default value is TRUE.
         //
         DefaultData.Type    = DefaultValueFromFlag;
         DefaultData.Value.b = TRUE;
@@ -2518,7 +2518,7 @@ ParseIfrData (
       DefaultData.DefaultId   = VarDefaultId;
       if ((IfrCheckBox->Flags & EFI_IFR_CHECKBOX_DEFAULT_MFG) == 
EFI_IFR_CHECKBOX_DEFAULT_MFG) {
         //
-        // When flag is set, defautl value is TRUE.
+        // When flag is set, default value is TRUE.
         //
         DefaultData.Type    = DefaultValueFromFlag;
         DefaultData.Value.b = TRUE;
@@ -2534,7 +2534,7 @@ ParseIfrData (
       }
       if (SmallestIdFromFlag) {
         //
-        // When smallest default Id is given by the  flag of CheckBox, set 
defaut value with TRUE for other default Id in the DefaultId list.
+        // When smallest default Id is given by the  flag of CheckBox, set 
default value with TRUE for other default Id in the DefaultId list.
         //
         DefaultData.Type    = DefaultValueFromOtherDefault;
         DefaultData.Value.b = TRUE;
@@ -2548,7 +2548,7 @@ ParseIfrData (
         }
       } else {
         //
-        // When flag is not set, defautl value is FASLE.
+        // When flag is not set, default value is FASLE.
         //
         DefaultData.Type    = DefaultValueFromDefault;
         DefaultData.Value.b = FALSE;
@@ -2943,7 +2943,7 @@ ParseIfrData (
 
       //
       // After insert the default value, reset the cleaned value for next 
-      // time used. If not set here, need to set the value before everytime 
+      // time used. If not set here, need to set the value before every time 
       // use it.
       //
       DefaultData.Cleaned     = FALSE;
@@ -3743,7 +3743,7 @@ GenerateAltConfigResp (
                                  When Request points to NULL, the default 
value string 
                                  for each varstore in form package will be 
merged into 
                                  a <MultiConfigAltResp> format string and 
return.
-  @param  PointerProgress        Optional parameter, it can be be NULL. 
+  @param  PointerProgress        Optional parameter, it can be NULL. 
                                  When it is not NULL, if Request is NULL, it 
returns NULL. 
                                  On return, points to a character in the 
Request
                                  string. Points to the string's null 
terminator if
@@ -3807,7 +3807,7 @@ GetFullStringFromHiiFormPackages (
   }
 
   //
-  // 1. Get the request block array by Request String when Request string 
containts the block array.
+  // 1. Get the request block array by Request String when Request string 
contains the block array.
   //
   StringPtr = NULL;
   if (*Request != NULL) {
@@ -3890,7 +3890,7 @@ GetFullStringFromHiiFormPackages (
   //
 
   //
-  // Parse the opcode in form pacakge to get the default setting.
+  // Parse the opcode in form package to get the default setting.
   //
   Status = ParseIfrData (DataBaseRecord->Handle,
                          HiiFormPackage,
@@ -3936,7 +3936,7 @@ GetFullStringFromHiiFormPackages (
   }
 
   //
-  // 5. Merge string into the input AltCfgResp if the iput *AltCfgResp is not 
NULL.
+  // 5. Merge string into the input AltCfgResp if the input *AltCfgResp is not 
NULL.
   //
   if (*AltCfgResp != NULL && DefaultAltCfgResp != NULL) {
     Status = MergeDefaultString (AltCfgResp, DefaultAltCfgResp);
@@ -4009,7 +4009,7 @@ Done:
   }
 
   //
-  // Free Pacakge data
+  // Free Package data
   //
   if (HiiFormPackage != NULL) {
     FreePool (HiiFormPackage);
@@ -4675,7 +4675,7 @@ HiiConfigRoutingExtractConfig (
 
     //
     // Attach this <ConfigAltResp> to a <MultiConfigAltResp>. There is a '&'
-    // which seperates the first <ConfigAltResp> and the following ones.
+    // which separates the first <ConfigAltResp> and the following ones.
     //
     ASSERT (*AccessProgress == 0);
 
@@ -4928,7 +4928,7 @@ HiiConfigRoutingExportConfig (
       
       //
       // Attach this <ConfigAltResp> to a <MultiConfigAltResp>. There is a '&'
-      // which seperates the first <ConfigAltResp> and the following ones.     
 
+      // which separates the first <ConfigAltResp> and the following ones.     
 
       //
       if (!FirstElement) {
@@ -1021,7 +1021,7 @@ MergeDefaultString (
   
   //
-  // Get the requestr ConfigHdr
+  // Get the request ConfigHdr
   //
   SizeAltCfgResp  = 0;
         Status = AppendToMultiString (Results, L"&");
-- 
2.9.0.windows.1

_______________________________________________
edk2-devel mailing list
edk2-devel@lists.01.org
https://lists.01.org/mailman/listinfo/edk2-devel

Reply via email to